window.Gleam.initSearch([{"doc":"party","title":"party","content":"# party\n\n[![Package Version](https://img.shields.io/hexpm/v/party)](https://hex.pm/packages/party)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/party/)\n\nA little parser combinator library for Gleam!\n\nA little demo:\n```gleam\nfn identstring() -&gt; Parser(String, e) {\n  use first &lt;- do(lowercase_letter())\n  use rest &lt;- do(many_concat(either(alphanum(), char(&quot;_&quot;))))\n  return(first &lt;&gt; rest)\n}\n```\n\n## Installation\n\nIf available on Hex this package can be added to your Gleam project:\n\n```sh\ngleam add party\n```\n\nand its documentation can be found at &lt;https://hexdocs.pm/party&gt;.\n","url":"index.html"},{"doc":"party","title":"ParseError","content":"pub type ParseError(e) {\n  Unexpected(pos: Position, error: String)\n  UserError(pos: Position, error: e)\n}\n The custom error type for the parser, \n which can itself be parameterized by a user-defined error type.\n The user-defined error type is useful for, for example, \n adding a `int.parse` call into your parser pipeline.\n See `try` for using this feature.\nUnexpected(pos: Position, error: String)\n\n\nUserError(pos: Position, error: e)\n\n\nSynonyms:\nparty.ParseError\nparty ParseError","url":"party.html#ParseError"},{"doc":"party","title":"Parser","content":"pub opaque type Parser(a, e)\n The parser type, parameterized by the type it parses and \n the user-defined error type it can return.\n\nSynonyms:\nparty.Parser\nparty Parser","url":"party.html#Parser"},{"doc":"party","title":"Position","content":"pub type Position {\n  Position(row: Int, col: Int)\n}\n The type for positions within a string.\nPosition(row: Int, col: Int)\n\n\nSynonyms:\nparty.Position\nparty Position","url":"party.html#Position"},{"doc":"party","title":"all","content":"pub fn all(ps: List(Parser(a, b))) -&gt; Parser(a, b)\n Do each parser in the list, returning the result of the last parser.\nSynonyms:\nparty.all\nparty all","url":"party.html#all"},{"doc":"party","title":"alphanum","content":"pub fn alphanum() -&gt; Parser(String, a)\n Parse an alphanumeric character.\nSynonyms:\nparty.alphanum\nparty alphanum","url":"party.html#alphanum"},{"doc":"party","title":"char","content":"pub fn char(c: String) -&gt; Parser(String, a)\n Parse a specific character.\nSynonyms:\nparty.char\nparty char","url":"party.html#char"},{"doc":"party","title":"choice","content":"pub fn choice(ps: List(Parser(a, b))) -&gt; Parser(a, b)\n Parse with the first parser in the list that doesn&#39;t fail.\nSynonyms:\nparty.choice\nparty choice","url":"party.html#choice"},{"doc":"party","title":"digit","content":"pub fn digit() -&gt; Parser(String, a)\n Parse a digit.\nSynonyms:\nparty.digit\nparty digit","url":"party.html#digit"},{"doc":"party","title":"digits","content":"pub fn digits() -&gt; Parser(String, a)\n Parse a sequence of digits.\nSynonyms:\nparty.digits\nparty digits","url":"party.html#digits"},{"doc":"party","title":"do","content":"pub fn do(\n  p: Parser(a, b),\n  f: fn(a) -&gt; Parser(c, b),\n) -&gt; Parser(c, b)\n A monadic bind for pleasant interplay with gleam&#39;s `use` syntax.\n example: \n \n fn identifier() -&gt; Parser(String, e) {\n     use pos &lt;- do(pos())\n     use first &lt;- do(lowercase_letter())\n     use rest &lt;- do(many(either(alphanum(), char(&quot;_&quot;))))\n     return(Ident(pos, first &lt;&gt; string.concat(rest)))\n }\n \nSynonyms:\nparty.do\nparty do","url":"party.html#do"},{"doc":"party","title":"either","content":"pub fn either(p: Parser(a, b), q: Parser(a, b)) -&gt; Parser(a, b)\n Parse the first parser, or the second if the first fails.\nSynonyms:\nparty.either\nparty either","url":"party.html#either"},{"doc":"party","title":"end","content":"pub fn end() -&gt; Parser(Nil, a)\n Parses successfully only when at the end of the input string.\nSynonyms:\nparty.end\nparty end","url":"party.html#end"},{"doc":"party","title":"error_map","content":"pub fn error_map(p: Parser(a, b), f: fn(b) -&gt; c) -&gt; Parser(a, c)\n Transform the user-defined error type \n with a user-provided conversion function.\nSynonyms:\nparty.error_map\nparty error_map","url":"party.html#error_map"},{"doc":"party","title":"fail","content":"pub fn fail() -&gt; Parser(a, b)\n Immediately fail regardless of the next input.\nSynonyms:\nparty.fail\nparty fail","url":"party.html#fail"},{"doc":"party","title":"go","content":"pub fn go(\n  p: Parser(a, b),\n  src: String,\n) -&gt; Result(a, ParseError(b))\n Apply a parser to a string.\nSynonyms:\nparty.go\nparty go","url":"party.html#go"},{"doc":"party","title":"lazy","content":"pub fn lazy(p: fn() -&gt; Parser(a, b)) -&gt; Parser(a, b)\n Run a parser as normal, but the parser itself isn&#39;t evaluated until it is used.\n This is needed for recursive grammars, such as `E := n | E + E` where `n` is a number.\n Example: `lazy(digit)` instead of `digit()`.\nSynonyms:\nparty.lazy\nparty lazy","url":"party.html#lazy"},{"doc":"party","title":"letter","content":"pub fn letter() -&gt; Parser(String, a)\n Parse a lowercase or uppercase letter.\nSynonyms:\nparty.letter\nparty letter","url":"party.html#letter"},{"doc":"party","title":"lowercase_letter","content":"pub fn lowercase_letter() -&gt; Parser(String, a)\n Parse a lowercase letter.\nSynonyms:\nparty.lowercase_letter\nparty lowercase_letter","url":"party.html#lowercase_letter"},{"doc":"party","title":"many","content":"pub fn many(p: Parser(a, b)) -&gt; Parser(List(a), b)\n Keep trying the parser until it fails, and return the array of parsed results.\n This cannot fail because it parses zero or more times!\nSynonyms:\nparty.many\nparty many","url":"party.html#many"},{"doc":"party","title":"many1","content":"pub fn many1(p: Parser(a, b)) -&gt; Parser(List(a), b)\n Keep trying the parser until it fails, and return the array of parsed results.\n This can fail, because it must parse successfully at least once!\nSynonyms:\nparty.many1\nparty many1","url":"party.html#many1"},{"doc":"party","title":"many1_concat","content":"pub fn many1_concat(p: Parser(String, a)) -&gt; Parser(String, a)\n Parse a certain string as many times as possible, returning everything that was parsed.\n This can fail, because it must parse successfully at least once!\nSynonyms:\nparty.many1_concat\nparty many1_concat","url":"party.html#many1_concat"},{"doc":"party","title":"many_concat","content":"pub fn many_concat(p: Parser(String, a)) -&gt; Parser(String, a)\n Parse a certain string as many times as possible, returning everything that was parsed.\n This cannot fail because it parses zero or more times!\nSynonyms:\nparty.many_concat\nparty many_concat","url":"party.html#many_concat"},{"doc":"party","title":"map","content":"pub fn map(p: Parser(a, b), f: fn(a) -&gt; c) -&gt; Parser(c, b)\n Do `p`, then apply `f` to the result if it succeeded.\nSynonyms:\nparty.map\nparty map","url":"party.html#map"},{"doc":"party","title":"not","content":"pub fn not(p: Parser(a, b)) -&gt; Parser(Nil, b)\n Negate a parser: if it succeeds, this fails, and vice versa.\n Example: `seq(string(&quot;if&quot;), not(either(alphanum(), char(&quot;_&quot;))))`\nSynonyms:\nparty.not\nparty not","url":"party.html#not"},{"doc":"party","title":"perhaps","content":"pub fn perhaps(p: Parser(a, b)) -&gt; Parser(Result(a, Nil), b)\n Try running a parser, but still succeed (with `Error(Nil)`) if it failed.\nSynonyms:\nparty.perhaps\nparty perhaps","url":"party.html#perhaps"},{"doc":"party","title":"pos","content":"pub fn pos() -&gt; Parser(Position, a)\n Get the current parser position.\nSynonyms:\nparty.pos\nparty pos","url":"party.html#pos"},{"doc":"party","title":"return","content":"pub fn return(x: a) -&gt; Parser(a, b)\n A monadic return for pleasant interplay with gleam&#39;s `use` syntax.\n see `do` for more details and an example.\n This is redundant if the last `do` is a `map` instead.\n But I prefer using it, stylistically.\nSynonyms:\nparty.return\nparty return","url":"party.html#return"},{"doc":"party","title":"satisfy","content":"pub fn satisfy(\n  when pred: fn(String) -&gt; Bool,\n) -&gt; Parser(String, a)\n Parse a character if it matches the predicate.\nSynonyms:\nparty.satisfy\nparty satisfy","url":"party.html#satisfy"},{"doc":"party","title":"sep","content":"pub fn sep(\n  parser: Parser(a, b),\n  by s: Parser(c, b),\n) -&gt; Parser(List(a), b)\n Parse a sequence separated by the given separator parser.\nSynonyms:\nparty.sep\nparty sep","url":"party.html#sep"},{"doc":"party","title":"sep1","content":"pub fn sep1(\n  parser: Parser(a, b),\n  by s: Parser(c, b),\n) -&gt; Parser(List(a), b)\n Parse a sequence separated by the given separator parser.\n This only succeeds if at least one element of the sequence was parsed.\nSynonyms:\nparty.sep1\nparty sep1","url":"party.html#sep1"},{"doc":"party","title":"seq","content":"pub fn seq(p: Parser(a, b), q: Parser(c, b)) -&gt; Parser(c, b)\n Do the first parser, ignore its result, then do the second parser.\nSynonyms:\nparty.seq\nparty seq","url":"party.html#seq"},{"doc":"party","title":"string","content":"pub fn string(s: String) -&gt; Parser(String, a)\n Parse an exact string of characters.\nSynonyms:\nparty.string\nparty string","url":"party.html#string"},{"doc":"party","title":"try","content":"pub fn try(\n  p: Parser(a, b),\n  f: fn(a) -&gt; Result(c, b),\n) -&gt; Parser(c, b)\n Do `p`, the apply `f` to the result if it succeeded.\n `f` itself can fail with the user-defined error type, \n and if it does the result is a `UserError` with the error.\nSynonyms:\nparty.try\nparty try","url":"party.html#try"},{"doc":"party","title":"until","content":"pub fn until(\n  do p: Parser(a, b),\n  until terminator: Parser(c, b),\n) -&gt; Parser(List(a), b)\n Parse zero or more repetitions of a parser, collecting the results into a list.\n Stop when the terminator parser succeeds, even if the looping parser would also succeed.\n The terminator parser&#39;s results are consumed and discarded.\n The main motivator for `until` is multiline comments ending in `*/`, `--&gt;`, `-}`, `*)`, etc.\nSynonyms:\nparty.until\nparty until","url":"party.html#until"},{"doc":"party","title":"uppercase_letter","content":"pub fn uppercase_letter() -&gt; Parser(String, a)\n Parse an uppercase letter.\nSynonyms:\nparty.uppercase_letter\nparty uppercase_letter","url":"party.html#uppercase_letter"},{"doc":"party","title":"whitespace","content":"pub fn whitespace() -&gt; Parser(String, a)\n Parse zero or more whitespace characters.\nSynonyms:\nparty.whitespace\nparty whitespace","url":"party.html#whitespace"},{"doc":"party","title":"whitespace1","content":"pub fn whitespace1() -&gt; Parser(String, a)\n Parse one or more whitespace characters.\nSynonyms:\nparty.whitespace1\nparty whitespace1","url":"party.html#whitespace1"},{"doc":"party","title":"party","content":" A simple parser combinator library.\n Party is stable, though breaking changes might come in a far-future 2.0 or 3.0 release.","url":"party.html"}]);